package DBD::PO::st;

use strict;
use warnings;

use DBD::File;
use parent qw(-norequire DBD::File::st);

our $imp_data_size = 0;

1;

__END__

=head1 SUBROUTINES/METHODS

none

=cut